pub struct Content {Show 14 fields
stack: TemplateChild<Stack>,
room_history: TemplateChild<RoomHistory>,
invite_request: TemplateChild<InviteRequest>,
invite: TemplateChild<Invite>,
explore: TemplateChild<Explore>,
empty_page: TemplateChild<ToolbarView>,
empty_page_header_bar: TemplateChild<HeaderBar>,
verification_page: TemplateChild<ToolbarView>,
verification_page_header_bar: TemplateChild<HeaderBar>,
identity_verification_widget: TemplateChild<IdentityVerificationView>,
session: WeakRef<Session>,
only_view: Cell<bool>,
item_binding: RefCell<Option<Binding>>,
item: BoundObject<Object>,
}Fields
stack: TemplateChild<Stack>room_history: TemplateChild<RoomHistory>invite_request: TemplateChild<InviteRequest>invite: TemplateChild<Invite>explore: TemplateChild<Explore>empty_page: TemplateChild<ToolbarView>empty_page_header_bar: TemplateChild<HeaderBar>verification_page: TemplateChild<ToolbarView>verification_page_header_bar: TemplateChild<HeaderBar>identity_verification_widget: TemplateChild<IdentityVerificationView>session: WeakRef<Session>The current session.
only_view: Cell<bool>Whether this is the only visible view, i.e. there is no sidebar.
item_binding: RefCell<Option<Binding>>item: BoundObject<Object>The item currently displayed.
Implementations
Sourceimpl Content
impl Content
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Content
impl Content
Sourcepub(super) fn visible_page(&self) -> ContentPage
pub(super) fn visible_page(&self) -> ContentPage
The visible page of the content.
Sourcefn set_visible_page(&self, page: ContentPage)
fn set_visible_page(&self, page: ContentPage)
Set the visible page of the content.
Sourcefn set_session(&self, session: Option<&Session>)
fn set_session(&self, session: Option<&Session>)
Set the current session.
Sourcefn update_visible_child(&self)
fn update_visible_child(&self)
Update the visible child according to the current item.
Sourcepub(super) fn handle_paste_action(&self)
pub(super) fn handle_paste_action(&self)
Handle a paste action.
Sourcepub(super) fn header_bars(&self) -> [&HeaderBar; 6]
pub(super) fn header_bars(&self) -> [&HeaderBar; 6]
All the header bars of the children of the content.